@@ -1,10 +1,8 @@
 package Syntax::Keyword::Gather;
-
+$Syntax::Keyword::Gather::VERSION = '1.003000';
 use strict;
 use warnings;
 
-our $VERSION = '1.002004'; # VERSION
-
 # ABSTRACT: Implements the Perl 6 'gather/take' control structure in Perl 5
 
 use Carp 'croak';
@@ -40,6 +38,7 @@ sub take(@) {
    my $caller = caller;
    croak "Call to take not inside a gather block"
       unless ((caller 3)[3]||"") eq 'Syntax::Keyword::Gather::gather';
+   @_ = $_ unless @_;
    push @{$gatherers{$caller}[-1]}, @_;
    return 0+@_;
 }
@@ -51,7 +50,7 @@ sub break() {
 }
 
 package Syntax::Keyword::Gather::MagicArrayRef;
-
+$Syntax::Keyword::Gather::MagicArrayRef::VERSION = '1.003000';
 use overload
    'bool'   => sub { @{$_[0]} > 0      },
    '0+'     => sub { @{$_[0]} + 0      },
@@ -72,7 +71,7 @@ Syntax::Keyword::Gather - Implements the Perl 6 'gather/take' control structure
 
 =head1 VERSION
 
-version 1.002004
+version 1.003000
 
 =head1 SYNOPSIS
 
@@ -225,6 +224,18 @@ first line they have in common. We could gather the lines like this:
     }
  }
 
+If you like it really short, you can also gather-take $_ magically:
+
+my @numbers_with_two = gather {
+    for (1..20) {
+        take if /2/
+    }
+};
+# @numbers_with_two contains 2, 12, 20
+
+Be aware that $_ in Perl5 is a global variable rather than the
+current topic like in Perl6.
+
 =head1 HISTORY
 
 This module was forked from Damian Conway's L<Perl6::Gather> for a few reasons.
